FromLeStreamTagged

Trait FromLeStreamTagged 

pub trait FromLeStreamTagged: Sized {
    type Tag;

    // Required method
    fn from_le_stream_tagged<T>(
        tag: Self::Tag,
        bytes: T,
    ) -> Result<Option<Self>, Self::Tag>
       where T: Iterator<Item = u8>;
}
Parse an object from a stream of bytes with little endianness with a leading tag.

Required Associated Types

type Tag

The prefixed tag type.

Required Methods

fn from_le_stream_tagged<T>( tag: Self::Tag, bytes: T, ) -> Result<Option<Self>, Self::Tag>
where T: Iterator<Item = u8>,

Parse an object from a stream of bytes with little endianness having the respective tag prefix.

Errors

Returns the tag if it is invalid.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors