LeStream

Trait LeStream 

pub trait LeStream: Sized {
    // Required method
    fn le_stream<T>(self) -> LeStreamIterator<T, Self> ;
}
Extension trait for reading typed values from an iterator of bytes.

Required Methods

fn le_stream<T>(self) -> LeStreamIterator<T, Self>

Converts an iterator of little-endian bytes into an iterator of T.

Iteration stops when T::from_le_stream returns None, usually because the underlying byte iterator is exhausted or ends with an incomplete value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I> LeStream for I
where I: Iterator<Item = u8>,