pub trait TryFromLeStream<T>: TryFrom<T> {
// Required method
fn try_from_le_stream<I>(
bytes: I,
) -> Result<Self, Option<<Self as TryFrom<T>>::Error>>
where I: Iterator<Item = u8>;
}Expand description
Try to parse an object from a stream of bytes with little endianness.
Required Methods
Sourcefn try_from_le_stream<I>(
bytes: I,
) -> Result<Self, Option<<Self as TryFrom<T>>::Error>>
fn try_from_le_stream<I>( bytes: I, ) -> Result<Self, Option<<Self as TryFrom<T>>::Error>>
Try to parse an object from another type that can be parsed from a stream of bytes with little endianness.
Errors
Returns None if the stream terminates prematurely, or Some(error) if the conversion fails.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.