A library for reading and writing data in little-endian byte order.
Structs
- LeStream
Iterator - An iterator over a little endian byte stream.
- Prefixed
- A wrapper type that adds a size prefix to the data it contains.
Enums
- Error
- Error type for byte stream operations.
Traits
- Consume
- Consumes a stream of bytes with little endianness to crate an object.
- From
LeStream - Parse an object from a stream of bytes with little endianness.
- LeStream
- Extension trait on iterators to convert them into streams of deserializable types.
- ToLe
Stream - Convert an object to a stream of bytes with little endianness.
- TryFrom
LeStream - Try to parse an object from a stream of bytes with little endianness.