pub trait LeStream: Sized {
// Required method
fn le_stream<T>(self) -> LeStreamIterator<T, Self> ⓘ;
}Expand description
Extension trait on iterators to convert them into streams of deserializable types.
Required Methods
Sourcefn le_stream<T>(self) -> LeStreamIterator<T, Self> ⓘ
fn le_stream<T>(self) -> LeStreamIterator<T, Self> ⓘ
Convert an iterator of little endian bytes into a stream of deserializable types.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".