LeStream

Trait LeStream 

pub trait LeStream: Sized {
    // Required method
    fn le_stream<T>(self) -> LeStreamIterator<T, Self>;
}
Extension trait on iterators to convert them into streams of deserializable types.

Required Methods

fn le_stream<T>(self) -> LeStreamIterator<T, Self>

Convert an iterator of little endian bytes into a stream of deserializable types.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I> LeStream for I
where I: Iterator<Item = u8>,